@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -103,6 +103,18 @@
  * parent's child_proxies list. The synchronization here is also simple as
  * this happens in the parent proxy's thread, thus no locks are necessary.
  * 
+ * Interface list locking
+ *
+ * The interface list is manipulated from two threads simoultaneously:
+ *   1) the parent might add/remove interface to the list anytime
+ *   2) the child queries the list when it wants to communicate with the parent
+ *
+ * A race might occur when the list is being deleted and the child wants to
+ * communicate with the parent (for example: parent exits at the same time
+ * the child wants to call set_result). This is resolved by using a
+ * GStaticMutex in ZProxy called interfaces_lock. It is assumed that the
+ * ZProxyIface class does not touch the interfaces_lock in its destructor as
+ * in that case a deadlock might occur.
  */
 
 
@@ -728,7 +740,9 @@ void
 z_proxy_add_iface(ZProxy *self, ZProxyIface *iface)
 {
   z_object_ref(&iface->super);
+  g_static_mutex_lock(&self->interfaces_lock);
   self->interfaces = g_list_prepend(self->interfaces, iface);
+  g_static_mutex_unlock(&self->interfaces_lock);
 }
 
 /**
@@ -736,13 +750,18 @@ z_proxy_add_iface(ZProxy *self, ZProxyIface *iface)
  * @self: ZProxy instance
  * @iface: exported interface to delete
  *
- * This function deletes the interface specified in @iface from the
- * set of supported interfaces.
+ * This function deletes the interface specified in @iface from the set of
+ * supported interfaces. 
+ *
+ * NOTE: the locking implemented here assumes that the destructor for
+ * z_proxy_iface will not touch interfaces lock again.
  **/
 void
 z_proxy_del_iface(ZProxy *self, ZProxyIface *iface)
 {
+  g_static_mutex_lock(&self->interfaces_lock);
   self->interfaces = g_list_remove(self->interfaces, iface);
+  g_static_mutex_unlock(&self->interfaces_lock);
   z_object_unref(&iface->super);
 }
 
@@ -766,14 +785,21 @@ z_proxy_find_iface(ZProxy *self, ZClass *compat)
       z_proxy_log(self, CORE_ERROR, 3, "Internal error, trying to look up a non-ZProxyIface compatible interface;");
       return NULL;
     }
+  g_static_mutex_lock(&self->interfaces_lock);
   for (p = self->interfaces; p; p = p->next)
     {
       ZObject *obj;
+      ZProxyIface *iface;
       
       obj = (ZObject *) self->interfaces->data;
       if (z_object_is_compatible(obj, compat))
-        return (ZProxyIface *) z_object_ref(obj);
+        {
+          iface = (ZProxyIface *) z_object_ref(obj);
+          g_static_mutex_unlock(&self->interfaces_lock);
+          return iface;
+        }
     }
+  g_static_mutex_unlock(&self->interfaces_lock);
   return NULL;
 }
 
@@ -853,6 +879,7 @@ z_proxy_destroy_method(ZProxy *self)
   ZPolicyObj *handler;
   ZPolicyThread *thread;
   ZProxyVars *vars;
+  GList *ifaces, *p;
 
   z_proxy_enter(self);
   z_proxy_policy_destroy(self);
@@ -866,12 +893,19 @@ z_proxy_destroy_method(ZProxy *self)
       z_proxy_del_child(self, (ZProxy *) self->child_proxies->data);
     }
 
-    
-  while (self->interfaces)
+  g_static_mutex_lock(&self->interfaces_lock);
+  ifaces = self->interfaces;
+  self->interfaces = NULL;
+  g_static_mutex_unlock(&self->interfaces_lock);
+
+  while (ifaces)
     {
-      z_proxy_del_iface(self, (ZProxyIface *) self->interfaces->data);
+      z_object_unref((ZObject *) ifaces->data);
+      p = ifaces;
+      ifaces = ifaces->next;
+      g_list_free_1(p);
     }
-    
+  
   for (i = EP_CLIENT; i <= EP_SERVER; i++)
     {
       if (self->endpoints[i])
