@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -505,7 +505,7 @@ z_py_zorp_method_free(ZorpMethod *self)
 
 PyTypeObject z_py_zorp_method_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_method_type)
+  PyObject_HEAD_INIT(NULL)
   0,
   "Zorp method",
   sizeof(ZorpMethod),
@@ -712,7 +712,7 @@ PyMappingMethods z_py_zorp_hash_mapping =
 
 PyTypeObject z_py_zorp_hash_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_hash_type)
+  PyObject_HEAD_INIT(NULL)
   0,
   "Zorp hash",
   sizeof(ZorpHash),
@@ -992,7 +992,7 @@ PyMappingMethods z_py_zorp_dimhash_mapping =
 
 PyTypeObject z_py_zorp_dimhash_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_dimhash_type)
+  PyObject_HEAD_INIT(NULL)
   0,
   "Zorp Multidimensional hash",
   sizeof(ZorpDimHash),
