@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -82,7 +82,7 @@ static PyMethodDef py_zorp_attach_methods[] =
 
 PyTypeObject z_py_zorp_attach_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_attach_type)
+  PyObject_HEAD_INIT(&PyType_Type)
   0,
   "ZorpAttach",
   sizeof(ZorpAttach),
@@ -399,7 +399,7 @@ z_py_zorp_attach_new_instance(PyObject *s G_GNUC_UNUSED, PyObject *args)
   switch (protocol)
     {
     case ZD_PROTO_TCP:
-      params.tcp.timeout = 30;
+      params.tcp.timeout = 30000;
       params.tcp.tos = -1;
       if (!PyArg_ParseTupleAndKeywords(fake_args, keywords, "|iii", tcp_keywords, &params.tcp.timeout, &params.tcp.loose, &params.tcp.tos))
         {
