@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -62,7 +62,7 @@ PyMethodDef z_py_zorp_dispatch_funcs[] =
 
 PyTypeObject z_py_zorp_dispatch_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_dispatch_type)
+  PyObject_HEAD_INIT(&PyType_Type)
   0,
   "ZorpDispatch",
   sizeof(ZorpDispatch),
