@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -65,7 +65,7 @@ static PyMethodDef py_zorp_stream_methods[] =
 
 PyTypeObject z_py_zorp_stream_type = 
 {
-  PyObject_HEAD_INIT(&z_py_zorp_stream_type)
+  PyObject_HEAD_INIT(&PyType_Type)
   0,
   "ZorpStream",
   sizeof(ZorpStream),
