@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -316,7 +316,7 @@ finger_fetch_request(FingerProxy *self)
             This message say that zorp found an invalid character
             in finger request.
            */
-          z_proxy_log(self, FINGER_VIOLATION, 1, "invalid character, dropping request, line=%.*s", (gint) line_length, line);
+          z_proxy_log(self, FINGER_VIOLATION, 1, "Invalid character, dropping request; line='%.*s'", (gint) line_length, line);
           z_proxy_leave(self);
           return FALSE;
         }
@@ -329,7 +329,7 @@ finger_fetch_request(FingerProxy *self)
                 This message is about too long username found
                 in the request.
                */
-              z_proxy_log(self, FINGER_VIOLATION, 1, "Username too long, dropping request; line=%.*s", (gint) line_length, line);
+              z_proxy_log(self, FINGER_VIOLATION, 1, "Username too long, dropping request; line='%.*s'", (gint) line_length, line);
               z_proxy_leave(self);
               return FALSE;
             }
