@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -588,8 +588,8 @@ ftp_data_reset(FtpProxy *self)
   
   if (self->data_local[EP_SERVER])
     {
-      self->data_local[EP_SERVER] = NULL;
       z_sockaddr_unref(self->data_local[EP_SERVER]);
+      self->data_local[EP_SERVER] = NULL;
     }
 
   self->data_state = 0;
@@ -1565,11 +1565,11 @@ ftp_answer_parse(FtpProxy *self)
 
   answer[3] = '\0'; /* zero terminate answer */
 
-  self->answer_cmd = g_string_assign(self->answer_cmd, answer);
+  g_string_assign(self->answer_cmd, answer);
 
   self->line[self->line_length] = 0;
   
-  self->answer_param = g_string_assign(self->answer_param, self->line + 4);
+  g_string_assign(self->answer_param, self->line + 4);
   
   /*LOG
     This message reports that a valid answer is read from the server.
@@ -1746,12 +1746,12 @@ ftp_command_parse(FtpProxy *self)
   gchar *src = self->line;
   guint i = 0;
 
-  self->request_cmd = g_string_assign(self->request_cmd, "");
+  g_string_assign(self->request_cmd, "");
 
   z_proxy_enter(self);
   while ((*src != ' ') && (i < self->line_length))
     {
-      self->request_cmd = g_string_append_c(self->request_cmd, *src++);
+      g_string_append_c(self->request_cmd, *src++);
       i++;
     }
 
@@ -1759,16 +1759,16 @@ ftp_command_parse(FtpProxy *self)
   i++;
   
   if (i < self->line_length)
-    self->request_param = g_string_assign(self->request_param, src);
+    g_string_assign(self->request_param, src);
   else
-    self->request_param = g_string_assign(self->request_param, "");
+    g_string_assign(self->request_param, "");
 
   /*LOG
     This message reports that a valid request is fetched from the client.
    */
   z_proxy_log(self, FTP_REQUEST, 6, "Request fetched; req='%s' req_prm='%s'", self->request_cmd->str, self->request_param->str);
 
-  self->request_cmd = g_string_up(self->request_cmd);
+  g_string_up(self->request_cmd);
       
   self->command_desc = ftp_command_hash_get(self->request_cmd->str);
 
@@ -2009,7 +2009,7 @@ ftp_proto_nt_client_to_proxy(FtpProxy *self)
         {
           self->state = FTP_NT_SERVER_TO_PROXY;
           self->ftp_state = FTP_STATE_PRECONNECT;
-          self->request_cmd = g_string_assign(self->request_cmd, "");
+          g_string_assign(self->request_cmd, "");
         }
       else
         self->state = FTP_QUIT;
@@ -2028,7 +2028,7 @@ ftp_proto_nt_server_to_proxy(FtpProxy *self)
   gboolean continued = TRUE;
 
   z_proxy_enter(self);
-  self->answer_cmd = g_string_assign(self->answer_cmd, "");
+  g_string_assign(self->answer_cmd, "");
   self->answer_code = 0;
   self->answer_cont = 0;
 
@@ -2070,7 +2070,7 @@ ftp_proto_nt_server_to_proxy(FtpProxy *self)
           gchar user_line[self->username->len + 6];
 
           g_snprintf(user_line, sizeof(user_line), "USER %s", self->username->str);
-          self->request_cmd = g_string_assign(self->request_cmd, "USER");
+          g_string_assign(self->request_cmd, "USER");
           ftp_command_write(self, user_line);
           self->ftp_state = FTP_STATE_PRECONNECT_LOGIN_U;
         }
@@ -2082,7 +2082,7 @@ ftp_proto_nt_server_to_proxy(FtpProxy *self)
 
           /* send password */
           g_snprintf(pass_line, sizeof(pass_line), "PASS %s", self->password->str);
-          self->request_cmd = g_string_assign(self->request_cmd, "PASS");
+          g_string_assign(self->request_cmd, "PASS");
           ftp_command_write(self, pass_line);
           self->ftp_state = FTP_STATE_LOGIN_P;
           self->state = FTP_SERVER_TO_CLIENT;
@@ -2137,7 +2137,7 @@ ftp_proto_server_to_client(FtpProxy *self)
   gboolean first = TRUE;
 
   z_proxy_enter(self);
-  self->answer_cmd = g_string_assign(self->answer_cmd, "");
+  g_string_assign(self->answer_cmd, "");
   self->answer_code = 0;
   self->answer_cont = 0;
 
