@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -197,7 +197,7 @@ ftp_command_parse_USER(FtpProxy *self)
         
       g_string_assign(self->hostname, atsign + 1);
       
-      self->username = g_string_assign(self->username, self->request_param->str);
+      g_string_assign(self->username, self->request_param->str);
       if (ddot)
         {
           self->hostport = atoi(ddot + 1);
@@ -256,7 +256,7 @@ ftp_command_parse_USER(FtpProxy *self)
           z_proxy_leave(self);
           return FTP_REQ_REJECT;
         }
-      self->username = g_string_assign(self->username, self->request_param->str);
+      g_string_assign(self->username, self->request_param->str);
       self->ftp_state = FTP_STATE_LOGIN_U;
       break;
     case FTP_STATE_CONVERSATION:
@@ -329,7 +329,7 @@ ftp_command_parse_PASS(FtpProxy *self)
           z_proxy_leave(self);
           return FTP_REQ_REJECT;
         }
-      self->password = g_string_assign(self->password, self->request_param->str);
+      g_string_assign(self->password, self->request_param->str);
       self->ftp_state = FTP_STATE_PRECONNECT_LOGIN_P;
       z_proxy_leave(self);
       return FTP_NOOP;
@@ -354,7 +354,7 @@ ftp_command_parse_PASS(FtpProxy *self)
           z_proxy_leave(self);
           return FTP_REQ_REJECT;
         }
-      self->password = g_string_assign(self->password, self->request_param->str);
+      g_string_assign(self->password, self->request_param->str);
       self->ftp_state = FTP_STATE_LOGIN_P;
       break;
     case FTP_STATE_CONVERSATION:
@@ -625,8 +625,8 @@ ftp_command_parse_TYPE(FtpProxy *self)
         case 'i':
         case 'I':
           g_string_truncate(self->request_param, 0);
-          self->request_param = g_string_append_c(self->request_param, toupper(mytype));
-          self->request_param = g_string_up(self->request_param);
+          g_string_append_c(self->request_param, toupper(mytype));
+          g_string_up(self->request_param);
           break;
         case 'l':
         case 'L':
@@ -727,7 +727,7 @@ ftp_command_parse_noarg(FtpProxy *self)
   switch (self->ftp_state)
   {
   case FTP_STATE_CONVERSATION:
-    self->request_param = g_string_assign(self->request_param, "");
+    g_string_assign(self->request_param, "");
     break;
   default:
     SET_ANSWER(MSG_COMMAND_NOT_ALLOWED_HERE);
@@ -776,7 +776,7 @@ ftp_command_parse_MODE(FtpProxy *self)
         case 'c':
         case 'C':
           g_string_truncate(self->request_param, 0);
-          self->request_param = g_string_append_c(self->request_param, toupper(mymode));
+          g_string_append_c(self->request_param, toupper(mymode));
           break;
         default:
           /*LOG
@@ -845,7 +845,7 @@ ftp_command_parse_STRU(FtpProxy *self)
         case 'f':
         case 'F':
           g_string_truncate(self->request_param, 0);
-          self->request_param = g_string_append_c(self->request_param, toupper(mystru));
+          g_string_append_c(self->request_param, toupper(mystru));
           break;
         default:
           SET_ANSWER(MSG_COMMAND_NOT_RECOGNIZED);
@@ -1199,8 +1199,8 @@ ftp_command_parse_PORT(FtpProxy *self)
       switch (self->data_mode)
         {
         case FTP_DATA_PASSIVE:
-           self->request_cmd = g_string_assign(self->request_cmd, "PASV");
-           self->request_param = g_string_assign(self->request_param, "");
+           g_string_assign(self->request_cmd, "PASV");
+           g_string_assign(self->request_param, "");
            break;
         case FTP_DATA_ACTIVE:
         case FTP_DATA_KEEP:
@@ -1446,7 +1446,7 @@ ftp_command_answer_PASV(FtpProxy *self)
                     {
                       *start = 0;
                       end = strchr(start, ')');
-                      self->answer_param = g_string_assign(self->answer_param, tmpline);
+                      g_string_assign(self->answer_param, tmpline);
                     }
 
                   g_string_append_printf(self->answer_param, "(%s,%d,%d)%s", tmpaddr, (port & 0xff00) >> 8, port & 0x00ff, end ? end + 1 : "");
@@ -1476,7 +1476,7 @@ ftp_command_answer_PASV(FtpProxy *self)
                   return FTP_RSP_REJECT;
                 }
 
-              self->answer_cmd = g_string_assign(self->answer_cmd, "227");
+              g_string_assign(self->answer_cmd, "227");
 
               if (self->masq_address[EP_CLIENT]->len)
                 g_strlcpy(tmpaddr, self->masq_address[EP_CLIENT]->str, sizeof(tmpaddr));
@@ -1625,8 +1625,8 @@ ftp_command_parse_EPRT(FtpProxy *self)
       switch (self->data_mode)
         {
         case FTP_DATA_PASSIVE:
-           self->request_cmd = g_string_assign(self->request_cmd, "EPSV");
-           self->request_param = g_string_assign(self->request_param, "");
+           g_string_assign(self->request_cmd, "EPSV");
+           g_string_assign(self->request_param, "");
            break;
         case FTP_DATA_ACTIVE:
         case FTP_DATA_KEEP:
@@ -1755,7 +1755,7 @@ ftp_command_parse_EPSV(FtpProxy *self)
   switch (self->ftp_state)
     {
     case FTP_STATE_CONVERSATION:
-      self->request_param = g_string_assign(self->request_param, "");
+      g_string_assign(self->request_param, "");
       self->data_state = 0;
 
       switch (self->data_mode)
@@ -1764,8 +1764,8 @@ ftp_command_parse_EPSV(FtpProxy *self)
         case FTP_DATA_PASSIVE:
           break;
         case FTP_DATA_ACTIVE:
-          self->request_cmd = g_string_assign(self->request_cmd, "EPRT");
-          self->request_param = g_string_assign(self->request_param, "");
+          g_string_assign(self->request_cmd, "EPRT");
+          g_string_assign(self->request_param, "");
           res = ftp_data_server_start_EPRT(self);
           break;
         default:
@@ -1846,13 +1846,13 @@ ftp_command_answer_EPSV(FtpProxy *self)
                     {
                       *start = 0;
                       end = strchr(start + 1, ')');
-                      self->answer_param = g_string_assign(self->answer_param, tmpline);
+                      g_string_assign(self->answer_param, tmpline);
                     }
 
                   g_string_append_printf(self->answer_param, "(|||%d|)", port);
 
                   if (end)
-                    self->answer_param = g_string_append(self->answer_param, end + 1);
+                    g_string_append(self->answer_param, end + 1);
                 }
               self->ftp_state = FTP_STATE_DATA;
               break;
@@ -1880,7 +1880,7 @@ ftp_command_answer_EPSV(FtpProxy *self)
                   return FTP_RSP_REJECT;
                 }
 
-              self->answer_cmd = g_string_assign(self->answer_cmd, "229");
+              g_string_assign(self->answer_cmd, "229");
 
               port = ntohs(((struct sockaddr_in *) &self->data_local[EP_CLIENT]->sa)->sin_port);
               if(port==0)
@@ -2043,10 +2043,10 @@ ftp_command_answer_REIN(FtpProxy *self)
       return FTP_NOOP;
     case '2':
       /* FIXME: ughh... I can't see how this code is relevant here ... */
-      /* REFIX: It's set the state before login. */
+      /* REFIX: This code set the state before login. */
       self->ftp_state = FTP_STATE_LOGIN;
-      self->username = g_string_assign(self->username, "");
-      self->password = g_string_assign(self->password, "");
+      g_string_assign(self->username, "");
+      g_string_assign(self->password, "");
       break;
     }
   return FTP_RSP_ACCEPT;
