@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -54,7 +54,6 @@ static TelnetOptions telnet_options_table[] =
   { 0,                                NULL }
 };
 
-
 /**
  * telnet_set_defaults:
  * @self: 
@@ -167,11 +166,13 @@ static GIOStatus
 telnet_stream_read(TelnetProxy *self, ZIOBuffer *buf, guint ep)
 {
   GIOStatus     res;
+  gint          len;
 
   z_proxy_enter(self);
 
-  buf->ofs = 0;
-  res = z_stream_read(self->super.endpoints[ep], buf->buf, sizeof(buf->buf), &buf->end, NULL);
+  len = 0;
+  res = z_stream_read(self->super.endpoints[ep], buf->buf + buf->end, sizeof(buf->buf) - buf->end, &len, NULL);
+  buf->end += len;
 
   switch (res)
     {
@@ -489,7 +490,7 @@ telnet_process_command(TelnetProxy *self, guint ep)
 static gboolean
 telnet_process_buf(TelnetProxy *self, ZIOBuffer *buf, ZIOBufferDyn *dbuf, ZIOBufferDyn *odbuf, guint ep)
 {
-  guint         ptr = buf->ofs;
+  guint         ptr;
   guint         res;
   guchar        byte;
   ZIOBuffer     *sbuf = &self->suboptions[ep];
@@ -501,6 +502,7 @@ telnet_process_buf(TelnetProxy *self, ZIOBuffer *buf, ZIOBufferDyn *dbuf, ZIOBuf
   
   dbuf->ofs = dbuf->end = 0;
   
+  ptr = buf->ofs;
   while (ptr < buf->end)
     {   
       z_proxy_log(self, TELNET_DEBUG, 7, "Processing buffer; state='%d'", self->state[ep]);
@@ -704,6 +706,10 @@ telnet_process_buf(TelnetProxy *self, ZIOBuffer *buf, ZIOBufferDyn *dbuf, ZIOBuf
                   self->state[ep] = TELNET_GOT_SB_IAC;
                   ptr++;
                 }
+              else
+                {
+                  self->state[ep] = TELNET_DATA;
+                }
             break;
 
             case TELNET_GOT_SB_IAC:
@@ -802,7 +808,11 @@ telnet_forward(TelnetProxy *self, ZStream *from, ZStream *to, guint ep)
   while (maxiter)
     {
       maxiter--;
-      buf->ofs = 0; buf->end = 0;
+      if (buf->ofs != buf->end)
+          memmove(buf->buf, buf->buf + buf->ofs, buf->end - buf->ofs);
+      buf->end -= buf->ofs;
+      buf->ofs = 0;
+
       res = telnet_stream_read(self, buf, ep);
       if (res == G_IO_STATUS_NORMAL)
         {
@@ -996,6 +1006,11 @@ telnet_init_streams(TelnetProxy *self)
       return FALSE;
     }
 
+  self->read_buffers[EP_SERVER].ofs = self->read_buffers[EP_SERVER].end = 0;
+  self->write_buffers[EP_SERVER].ofs = self->write_buffers[EP_SERVER].end = 0;
+  self->read_buffers[EP_CLIENT].ofs = self->read_buffers[EP_CLIENT].end = 0;
+  self->write_buffers[EP_CLIENT].ofs = self->write_buffers[EP_CLIENT].end = 0;
+
   z_stream_set_nonblock(self->super.endpoints[EP_CLIENT], TRUE);
 
   z_stream_set_callback(self->super.endpoints[EP_CLIENT],
