@@ -1,6 +1,6 @@
 ############################################################################
 ##
-## Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
+## Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -230,7 +230,7 @@ class FailoverChainer(ConnectChainer):
 
 	  current_host -- index of the last attempted destination
 	"""
-	def __init__(self, protocol=ZD_PROTO_TCP, timeout=0):
+	def __init__(self, protocol=ZD_PROTO_TCP, timeout=0, round_robin=TRUE):
 		"""Constructor to initialize a FailoverChainer class.
 
 		This constructor initializes a FailoverChainer class by
@@ -244,6 +244,8 @@ class FailoverChainer(ConnectChainer):
 		  protocol  -- [ENUM;ZD_PROTO] Type of Connecting method
 		  
 		  timeout   -- [INTEGER] the down state of remote hosts is kept for this interval in seconds
+		  
+		  round_robin -- [BOOLEAN] connections to hosts are attempted in round-robin fashion
 		"""
 		ConnectChainer.__init__(self, protocol)
 		if timeout:
@@ -251,6 +253,7 @@ class FailoverChainer(ConnectChainer):
 		else:
 			self.state = None
 		self.current_host = 0
+		self.round_robin = round_robin
 
 	def chainParent(self, session):
 		"""Overridden function to perform connection establishment.
@@ -287,6 +290,9 @@ class FailoverChainer(ConnectChainer):
 
 		if session.service.snat:
 			local = session.service.snat.performTranslation(session, local, NAT_SNAT)
+			
+		if not self.round_robin:
+			self.current_host = 0
 
 		stream = None
 		try_count = 0
@@ -321,8 +327,12 @@ class FailoverChainer(ConnectChainer):
 					##
 					log(None, CORE_MESSAGE, 4, "Destination is down, skipping; remote='%s'", (remote,))
 			if (stream == None) and (try_count == 0):
-				log(None, CORE_MESSAGE, 4, "All destinations are down, clearing cache and trying again;")
-				self.state.clear()
+				if self.state:
+					log(None, CORE_MESSAGE, 4, "All destinations are down, clearing cache and trying again;")
+					self.state.clear()
+				else:
+					# there was no state, tried all possible destinations, no point in trying again
+					break
 			try_count = try_count + 1
 		return stream
 
