@@ -1,6 +1,6 @@
 ############################################################################
 ##
-## Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
+## Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -199,6 +199,8 @@ class Proxy(ZorpProxy):
 		# This message reports that this proxy instance was destroyed and freed.
 		##
 		log(self.session.session_id, CORE_DEBUG, 6, "Proxy destroy; class='%s', module='%s'", (self.__class__.__name__, self.name))
+		# free possible circular references in __dict__ by removing all elements
+		self.__dict__.clear()
 
         def stackProxy(self, client_stream, server_stream, proxy_class):
                 """Function to actually stack a proxy within this proxy in a subsession.
