@@ -1,6 +1,6 @@
 ############################################################################
 ##
-## Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
+## Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -118,6 +118,7 @@ class AbstractZone:
 		self.inherit_name = inherit_name
 		self.domain = None
 		self.cached_name = None
+		self.umbrella = umbrella
 		if admin_parent:
 			self.admin_parent = Globals.zones[admin_parent]
 			self.admin_parent.addAdminChild(self)
@@ -127,96 +128,20 @@ class AbstractZone:
                 self.inbound_services = {}
                 self.outbound_services = {}
                 if outbound_services != None:
-			if type(outbound_services) == types.DictType:
-				for i in outbound_services["permitted"]:
-					try:
-						self.outbound_services[i] = self.outbound_services[i] + 1
-					except KeyError:
-						self.outbound_services[i] = 1
-					## LOG ##
-					# This message reports that this service is a "permitted" outbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Permitted outbound service; zone='%s', service='%s'", (self.name, i))
-
-				for i in outbound_services["effective"]:
-					try:
-						self.outbound_services[i] = self.outbound_services[i] + 2
-					except KeyError:
-						self.outbound_services[i] = 2
-					## LOG ##
-					# This message reports that this service is an "effective" outbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Effective outbound service; zone='%s', service='%s'", (self.name, i))
-
-				for i in outbound_services["inherited"]:
-					try:
-						self.outbound_services[i] = self.outbound_services[i] + 4
-					except KeyError:
-						self.outbound_services[i] = 4
-					## LOG ##
-					# This message reports that this service is an "inherited" outbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Inherited outbound service; zone='%s', service='%s'", (self.name, i))
-			else:
-				if umbrella:
-					rights = 6
-				else:
-					self.outbound_services["*"] = 5
-					rights = 7
-	                        for i in outbound_services:
-	                                self.outbound_services[i] = rights
-					## LOG ##
-					# This message reports that this service is an allowed outbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Outbound service; zone='%s', service='%s'", (self.name, i))
-		else:
-			self.outbound_services["*"] = 5
+                        for i in outbound_services:
+                                self.outbound_services[i] = 1
+				## LOG ##
+				# This message reports that this service is an allowed outbound service in that zone.
+				##
+				log(None, CORE_DEBUG, 5, "Outbound service; zone='%s', service='%s'", (self.name, i))
         
                 if inbound_services != None:
-			if type(inbound_services) == types.DictType:
-				for i in inbound_services["permitted"]:
-					try:
-						self.inbound_services[i] = self.inbound_services[i] + 1
-					except KeyError:
-						self.inbound_services[i] = 1
-					## LOG ##
-					# This message reports that this service is a "permitted" inbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Permitted inbound service; zone='%s', service='%s'", (self.name, i))
-
-				for i in inbound_services["effective"]:
-					try:
-						self.inbound_services[i] = self.inbound_services[i] + 2
-					except KeyError:
-						self.inbound_services[i] = 2
-					## LOG ##
-					# This message reports that this service is an "effective" inbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Effective inbound service; zone='%s', service='%s'", (self.name, i))
-
-				for i in inbound_services["inherited"]:
-					try:
-						self.inbound_services[i] = self.inbound_services[i] + 4
-					except KeyError:
-						self.inbound_services[i] = 4
-					## LOG ##
-					# This message reports that this service is an "inherited" inbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Inherited inbound service; zone='%s', service='%s'", (self.name, i))
-			else:
-				if umbrella:
-					rights = 6
-				else:
-					self.inbound_services["*"] = 5
-					rights = 7
-	                        for i in inbound_services:
-	                                self.inbound_services[i] = rights
-					## LOG ##
-					# This message reports that this service is an allowed inbound service in that zone.
-					##
-					log(None, CORE_DEBUG, 5, "Inbound service; zone='%s', service='%s'", (self.name, i))
-		else:
-			self.inbound_services["*"] = 5
+                        for i in inbound_services:
+                                self.inbound_services[i] = 1
+				## LOG ##
+				# This message reports that this service is an allowed inbound service in that zone.
+				##
+				log(None, CORE_DEBUG, 5, "Inbound service; zone='%s', service='%s'", (self.name, i))
 
 	def addAdminChild(self, child):
 		"""Function to add an administrative child
@@ -280,7 +205,7 @@ class AbstractZone:
 		"""
 		return "RootZone(%s)" % self.name
 
-        def isInboundServicePermitted(self, session, parent=FALSE):
+        def isInboundServicePermitted(self, session):
                 """Function to do inbound access control check.
                 
                 This function is called when a session is connecting to a server to
@@ -296,28 +221,15 @@ class AbstractZone:
                 
                   Z_ACCEPT if the service is permitted, Z_REJECT otherwise
                 """
-                try:
-                        t1 = self.inbound_services["*"]
-                except KeyError:
-                        t1 = 0
                 
-                try:
-                        t2 = self.inbound_services[session.service.name]
-                except KeyError:
-                        t2 = 0
+                if self.inbound_services.has_key(session.service.name) or self.inbound_services.has_key('*'):
+                        return Z_ACCEPT
+                elif self.admin_parent and not self.umbrella:
+               		return self.admin_parent.isInboundServicePermitted(session)
+               		
+                return Z_REJECT
                 
-		t = t1 | t2
-
-		if (not parent) or (t & 4):
-	                if t & 2:
-	                        return Z_ACCEPT
-	                elif t & 1:
-	                	if self.admin_parent:
-	                		return self.admin_parent.isInboundServicePermitted(session, TRUE)
-
-		return Z_REJECT
-                
-        def isOutboundServicePermitted(self, session, parent=FALSE):
+        def isOutboundServicePermitted(self, session):
                 """Function to do outbound access control check.
                 
                 This function is called when an incoming connection is
@@ -333,26 +245,12 @@ class AbstractZone:
                 
                   Z_ACCEPT if the service is permitted, Z_REJECT otherwise
                 """
-                try:
-                        t1 = self.outbound_services["*"]
-                except KeyError:
-                        t1 = 0
-                
-                try:
-                        t2 = self.outbound_services[session.service.name]
-                except KeyError:
-                        t2 = 0
-
-		t = t1 | t2
-                
-		if (not parent) or (t & 4):
-	                if t & 2:
-	                        return Z_ACCEPT
-	                elif t & 1:
-	                	if self.admin_parent:
-	                		return self.admin_parent.isOutboundServicePermitted(session, TRUE)
-
-		return Z_REJECT
+                if self.outbound_services.has_key(session.service.name) or self.outbound_services.has_key('*'):
+                        return Z_ACCEPT
+                elif self.admin_parent and not self.umbrella:
+               		return self.admin_parent.isOutboundServicePermitted(session)
+               		
+                return Z_REJECT
 
 	def getName(self):
 		if self.cached_name:
