@@ -1,6 +1,5 @@
-from Zorp import Zorp
+from Zorp.Core import *
 from Zorp.SockAddr import inet_ntoa
-from Zorp.Domain import InetDomain
 from traceback import print_exc
 
 true = 1
@@ -23,6 +22,7 @@ def init(name):
 		print 'exception: fail', e
 		print_exc()
 		Zorp.quit(1)
-		return
+		return 0
 
 	Zorp.quit(0)
+	return 1
